poissonL2T: Fitting of Poisson Generalized Linear Models
using MT method with L2 rho function
Description
poissonL2T is used to fit generalized linear models by MT
method with L2 rho function. The model is specified by the
x and y components. Since the L2 rho function is
used the method is not robust.
Usage
poissonL2T(x, y, start = NULL, tol = 1e-08, maxit = 100,
m.approx = NULL, mprime.approx = NULL, na.to.zero = TRUE)
Arguments
x
design matrix of dimension \(n \times p\).
y
vector of observations of length n.
start
starting values for the parameters in the linear predictor.
tol
convergence tolerance for the parameter vector.
maxit
integer specifying the maximum number of IRWLS iterations.
m.approx
a function that return the value, for each linear predictor, that
makes the estimating equation Fisher consistent. If NULL
the default internal function is used.
mprime.approx
a function that return the value, for each linear predictor,
corresponding to the first derivative of m.approx.
If NULL the default internal function is used.
na.to.zero
logical, should the eventual NA in the coefficients
be replaced by 0?
Value
A vector with the estimated coefficients.
References
C. Agostinelli, M. Valdora and V.J Yohai (2018)
Initial Robust Estimation in Generalized Linear Models
with a Large Number of Covariates. Submitted.
M. Valdora and V.J. Yohai (2014)
Robust estimators for generalized linear models.
Journal of Statistical Planning and Inference, 146, 31-48.